%define anolis_release 1

%global majmin %(echo %{version} | cut -d. -f1-2)

%global __provides_exclude_from ^(%{_qt5_archdatadir}/qml/.*\\.so|%{_qt5_plugindir}/.*\\.so)$

%global qt_module qtmultimedia

%bcond_without openal

%global gst 1.0

Name:    qt5-%{qt_module}
Summary: Qt5 - Multimedia support
Version: 5.15.9
Release: %{anolis_release}%{?dist}
License: LGPLv2 with exceptions or GPLv3 with exceptions
Url:     http://www.qt.io
Source0: https://download.qt.io/official_releases/qt/%{majmin}/%{version}/submodules/%{qt_module}-everywhere-opensource-src-%{version}.tar.xz
Patch0001: 0001-%{name}-gcc11.patch

BuildRequires: make
BuildRequires: wayland-devel
BuildRequires: qt5-qtbase-devel >= %{version} qt5-qtbase-private-devel
%{?_qt5:Requires: %{_qt5} = %{_qt5_version}}
BuildRequires: qt5-qtdeclarative-devel >= %{version} pkgconfig(alsa)
%if "%{?gst}" == "0.10"
BuildRequires: pkgconfig(gstreamer-interfaces-0.10)
%endif
BuildRequires: pkgconfig(gstreamer-%{gst}) pkgconfig(gstreamer-app-%{gst}) pkgconfig(xv)
BuildRequires: pkgconfig(gstreamer-audio-%{gst}) pkgconfig(gstreamer-base-%{gst})
BuildRequires: pkgconfig(gstreamer-pbutils-%{gst}) pkgconfig(gstreamer-plugins-bad-%{gst})
BuildRequires: pkgconfig(gstreamer-video-%{gst}) pkgconfig(libpulse) pkgconfig(libpulse-mainloop-glib)
%if %{with openal}
BuildRequires: pkgconfig(openal)
%endif

%description
%{name} is a library that provides multimedia functionality for Qt applications.
It includes modules for audio playback and recording, video playback and
recording, and camera support. It is a part of the Qt toolkit and allows developers
to create cross-platform multimedia applications.

%package devel
Summary: Development files for %{name}
Requires: %{name} = %{EVR}
Requires: qt5-qtbase-devel
Requires: qt5-qtdeclarative-devel
Requires: pkgconfig(libpulse-mainloop-glib)
%description devel
%{summary}.

%package examples
Summary: Programming examples for %{name}
Requires: %{name} = %{EVR}
%description examples
%{summary}.

%prep
%autosetup -n %{qt_module}-everywhere-src-%{version} -p1

%build
%{qmake_qt5} CONFIG+=git_build GST_VERSION=%{gst}

%make_build

%install
make install INSTALL_ROOT=%{buildroot}

pushd %{buildroot}%{_qt5_libdir}
for prl_file in *.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

%generate_compatibility_deps

%files
%license LICENSE.*
%dir %{abidir}
%{_qt5_libdir}/libQt5Multimedia.so.5*
%{_qt5_libdir}/libQt5MultimediaQuick.so.5*
%{_qt5_libdir}/libQt5MultimediaWidgets.so.5*
%{_qt5_libdir}/libQt5MultimediaGstTools.so.5*
%{abidir}/libQt5Multimedia.dump
%{abidir}/libQt5MultimediaGstTools.dump
%{abidir}/libQt5MultimediaQuick.dump
%{abidir}/libQt5MultimediaWidgets.dump
%{abidir}/libdeclarative_audioengine.dump
%{abidir}/libdeclarative_multimedia.dump
%{abidir}/libfftreal.dump
%{abidir}/libgstaudiodecoder.dump
%{abidir}/libgstcamerabin.dump
%{abidir}/libgstmediacapture.dump
%{abidir}/libgstmediaplayer.dump
%{abidir}/libqtaudio_alsa.dump
%{abidir}/libqtmedia_pulse.dump
%{abidir}/libqtmultimedia_m3u.dump
%if %{with openal}
%{_qt5_archdatadir}/qml/QtAudioEngine/
%endif
%{_qt5_plugindir}/audio/
%{_qt5_plugindir}/mediaservice/
%{_qt5_plugindir}/playlistformats/
%{_qt5_archdatadir}/qml/QtMultimedia/
%dir %{_qt5_libdir}/cmake/Qt5Multimedia/
%dir %{_qt5_libdir}/cmake/Qt5MultimediaWidgets/
%{_qt5_libdir}/cmake/Qt5Multimedia/Qt5Multimedia_*Plugin.cmake

%files devel
%{_qt5_headerdir}/QtMultimedia/
%{_qt5_headerdir}/QtMultimediaQuick/
%{_qt5_headerdir}/QtMultimediaWidgets/
%{_qt5_headerdir}/QtMultimediaGstTools/
%{_qt5_libdir}/libQt5Multimedia.so
%{_qt5_libdir}/libQt5Multimedia.prl
%{_qt5_libdir}/libQt5MultimediaQuick.so
%{_qt5_libdir}/libQt5MultimediaQuick.prl
%{_qt5_libdir}/libQt5MultimediaWidgets.so
%{_qt5_libdir}/libQt5MultimediaWidgets.prl
%{_qt5_libdir}/libQt5MultimediaGstTools.so
%{_qt5_libdir}/libQt5MultimediaGstTools.prl
%{_qt5_libdir}/pkgconfig/Qt5Multimedia.pc
%{_qt5_libdir}/pkgconfig/Qt5MultimediaWidgets.pc
%{_qt5_archdatadir}/mkspecs/modules/*.pri
%{_qt5_libdir}/cmake/Qt5Multimedia/Qt5MultimediaConfig*.cmake
%{_qt5_libdir}/cmake/Qt5MultimediaQuick/Qt5MultimediaQuickConfig*.cmake
%{_qt5_libdir}/cmake/Qt5MultimediaWidgets/Qt5MultimediaWidgetsConfig*.cmake
%{_qt5_libdir}/cmake/Qt5MultimediaGstTools/Qt5MultimediaGstToolsConfig*.cmake

%if 0%{?_qt5_examplesdir:1}
%files examples
%license LICENSE.FDL
%{_qt5_examplesdir}/
%endif

%changelog
* Tue May 23 2023 Funda Wang <fundawang@yeah.net> - 5.15.9-1
- New version 5.15.9

* Fri Apr 14 2023 Heng Qi <hengqi@linux.alibaba.com> - 5.15.8-2
- Refactor the spec file

* Thu Jan 19 2023 Funda Wang <fundawang@yeah.net> - 5.15.8-1
- New version 5.15.8

* Wed Dec 7 2022 Funda Wang <fundawang@yeah.net> - 5.15.7-1
- New version 5.15.7

* Thu Jul 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.15.5-1
- Init from upstream version 5.15.5
